@@ -48,7 +48,7 @@
 #include <KStandardDirs>
 #include <knewstuff3/downloaddialog.h>
 #ifdef Q_WS_X11
-#include <../../kwin/libkdecorations/kdecoration.h>
+#include <kdecoration.h>
 #endif
 
 
