@@ -420,8 +420,13 @@ Workspace::~Workspace()
     // TODO: grabXServer();
 
     // Use stacking_order, so that kwin --replace keeps stacking order
-    for (ToplevelList::iterator it = stacking_order.begin(), end = stacking_order.end(); it != end; ++it) {
-        Client *c = qobject_cast<Client*>(*it);
+    const ToplevelList stack = stacking_order;
+    // "mutex" the stackingorder, since anything trying to access it from now on will find
+    // many dangeling pointers and crash
+    stacking_order.clear();
+
+    for (ToplevelList::const_iterator it = stack.constBegin(), end = stack.constEnd(); it != end; ++it) {
+        Client *c = qobject_cast<Client*>(const_cast<Toplevel*>(*it));
         if (!c) {
             continue;
         }
@@ -1455,6 +1460,11 @@ QString Workspace::supportInformation() const
     } else {
         support.append("no\n");
     }
+    support.append("Active screen follows mouse: ");
+    if (screens()->isCurrentFollowsMouse())
+        support.append(" yes\n");
+    else
+        support.append(" no\n");
     support.append(QString("Number of Screens: %1\n").arg(screens()->count()));
     for (int i=0; i<screens()->count(); ++i) {
         const QRect geo = screens()->geometry(i);
@@ -1558,6 +1568,11 @@ QString Workspace::supportInformation() const
             } else {
                 support.append("OpenGL 2 Shaders are not used. Legacy OpenGL 1.x code path is used.\n");
             }
+            support.append("Painting blocks for vertical retrace: ");
+            if (m_compositor->scene()->blocksForRetrace())
+                support.append(" yes\n");
+            else
+                support.append(" no\n");
             break;
         }
         case XRenderCompositing:
