@@ -45,6 +45,7 @@
 
 #include "appinterface.h"
 #include "containment.h"
+#include "configgroup.h"
 #include "i18n.h"
 #include "layouttemplatepackagestructure.h"
 #include "widget.h"
@@ -349,6 +350,15 @@ QScriptValue ScriptEngine::applicationExists(QScriptContext *context, QScriptEng
     return false;
 }
 
+QString ScriptEngine::onlyExec(const QString &commandLine)
+{
+    if (commandLine.isEmpty()) {
+        return commandLine;
+    }
+
+    return KShell::splitArgs(commandLine, KShell::TildeExpand).first();
+}
+
 QScriptValue ScriptEngine::defaultApplication(QScriptContext *context, QScriptEngine *engine)
 {
     Q_UNUSED(engine)
@@ -373,17 +383,16 @@ QScriptValue ScriptEngine::defaultApplication(QScriptContext *context, QScriptEn
         QString command = settings.getSetting(KEMailSettings::ClientProgram);
         if (command.isEmpty()) {
             if (KService::Ptr kontact = KService::serviceByStorageId("kontact")) {
-                return storageId ? kontact->storageId() : kontact->exec();
+                return storageId ? kontact->storageId() : onlyExec(kontact->exec());
             } else if (KService::Ptr kmail = KService::serviceByStorageId("kmail")) {
-                return storageId ? kmail->storageId() : kmail->exec();
+                return storageId ? kmail->storageId() : onlyExec(kmail->exec());
             }
         }
 
         if (!command.isEmpty()) {
             if (settings.getSetting(KEMailSettings::ClientTerminal) == "true") {
                 KConfigGroup confGroup(KGlobal::config(), "General");
-                const QString preferredTerminal = confGroup.readPathEntry("TerminalApplication",
-                        QString::fromLatin1("konsole"));
+                const QString preferredTerminal = confGroup.readPathEntry("TerminalApplication", QString::fromLatin1("konsole"));
                 command = preferredTerminal + QString::fromLatin1(" -e ") + command;
             }
 
@@ -401,21 +410,21 @@ QScriptValue ScriptEngine::defaultApplication(QScriptContext *context, QScriptEn
             browserApp = browserApp.mid(1);
         }
 
-        return browserApp;
+        return onlyExec(browserApp);
     } else if (application.compare("terminal", Qt::CaseInsensitive) == 0) {
         KConfigGroup confGroup(KGlobal::config(), "General");
-        return confGroup.readPathEntry("TerminalApplication", QString::fromLatin1("konsole"));
+        return onlyExec(confGroup.readPathEntry("TerminalApplication", QString::fromLatin1("konsole")));
     } else if (application.compare("filemanager", Qt::CaseInsensitive) == 0) {
         KService::Ptr service = KMimeTypeTrader::self()->preferredService("inode/directory");
         if (service) {
-            return storageId ? service->storageId() : service->exec();
+            return storageId ? service->storageId() : onlyExec(service->exec());
         }
     } else if (application.compare("windowmanager", Qt::CaseInsensitive) == 0) {
         KConfig cfg("ksmserverrc", KConfig::NoGlobals);
         KConfigGroup confGroup(&cfg, "General");
-        return confGroup.readEntry("windowManager", QString::fromLatin1("konsole"));
+        return onlyExec(confGroup.readEntry("windowManager", QString::fromLatin1("kwin")));
     } else if (KService::Ptr service = KMimeTypeTrader::self()->preferredService(application)) {
-        return storageId ? service->storageId() : service->exec();
+        return storageId ? service->storageId() : onlyExec(service->exec());
     } else {
         // try the files in share/apps/kcm_componentchooser/
         const QStringList services = KGlobal::dirs()->findAllResources("data","kcm_componentchooser/*.desktop", KStandardDirs::NoDuplicates);
@@ -550,6 +559,32 @@ QScriptValue ScriptEngine::knownWallpaperPlugins(QScriptContext *context, QScrip
     return rv;
 }
 
+QScriptValue ScriptEngine::configFile(QScriptContext *context, QScriptEngine *engine)
+{
+    ConfigGroup *file = 0;
+
+    if (context->argumentCount() > 0) {
+        if (context->argument(0).isString()) {
+            file = new ConfigGroup;
+            file->setFile(context->argument(0).toString());
+            if (context->argumentCount() > 1) {
+                file->setGroup(context->argument(1).toString());
+            }
+        } else if (ConfigGroup *parent= qobject_cast<ConfigGroup *>(context->argument(0).toQObject())) {
+            file = new ConfigGroup(parent);
+        }
+    } else {
+        file = new ConfigGroup;
+    }
+
+    QScriptValue v = engine->newQObject(file,
+                                        QScriptEngine::ScriptOwnership,
+                                        QScriptEngine::ExcludeSuperClassProperties |
+                                        QScriptEngine::ExcludeSuperClassMethods);
+    return v;
+
+}
+
 void ScriptEngine::setupEngine()
 {
     QScriptValue v = globalObject();
@@ -577,6 +612,7 @@ void ScriptEngine::setupEngine()
     m_scriptSelf.setProperty("userDataPath", newFunction(ScriptEngine::userDataPath));
     m_scriptSelf.setProperty("applicationPath", newFunction(ScriptEngine::applicationPath));
     m_scriptSelf.setProperty("knownWallpaperPlugins", newFunction(ScriptEngine::knownWallpaperPlugins));
+    m_scriptSelf.setProperty("ConfigFile", newFunction(ScriptEngine::configFile));
 
     setGlobalObject(m_scriptSelf);
 }
