@@ -67,11 +67,11 @@ function full() {
     return (maxStripes() == calculateStripes());
 }
 
-function optimumCapacity() {
-    var length = tasks.vertical ? taskList.height : taskList.width;
+function optimumCapacity(width, height) {
+    var length = tasks.vertical ? height : width - (tasksModel.launcherCount * launcherWidth());
     var maximum = tasks.vertical ? preferredMaxHeight() : preferredMaxWidth();
 
-    return Math.ceil(length / maximum) * maxStripes();
+    return (Math.ceil(length / maximum) * maxStripes()) + tasksModel.launcherCount;
 }
 
 function layoutWidth() {
